@@ -1,7 +1,9 @@
 from .create_lxc import create_lxc
 from .shell_lxc import shell_lxc
+from .transport_lxc import transport_lxc
 
 __all__ = (
     "create_lxc",
     "shell_lxc",
+    "transport_lxc",
 )
